@@ -33,6 +33,8 @@ int xmlHashSize(xmlHashTablePtr table);
 #endif
 
 
+void RSXML_setErrorHandlers(void);
+
 
 USER_OBJECT_ RS_XML(RecursiveApply)(USER_OBJECT_ top, USER_OBJECT_ func, USER_OBJECT_ klasses);
 USER_OBJECT_ RS_XML(HtmlParseTree)(USER_OBJECT_ fileName, USER_OBJECT_ converterFunctions, 
@@ -54,7 +56,8 @@ RS_XML(ParseTree)(USER_OBJECT_ fileName, USER_OBJECT_ converterFunctions,
 		  USER_OBJECT_ skipBlankLines, USER_OBJECT_ replaceEntities,
 		  USER_OBJECT_ asText, USER_OBJECT_ trim, USER_OBJECT_ validate,
 		  USER_OBJECT_ getDTD, USER_OBJECT_ isURL,
-		  USER_OBJECT_ addNamespaceAttributes);
+		  USER_OBJECT_ addNamespaceAttributes, USER_OBJECT_ useInternalNodes,
+                   USER_OBJECT_ s_useHTML);
 
 USER_OBJECT_ R_newXMLDtd(USER_OBJECT_ sdoc, USER_OBJECT_ sname, USER_OBJECT_ sexternalID, USER_OBJECT_ ssysID);
 USER_OBJECT_ R_newXMLDoc(USER_OBJECT_ dtd, USER_OBJECT_ namespaces);
@@ -69,5 +72,9 @@ USER_OBJECT_ R_xmlSetNs(USER_OBJECT_ s_node, USER_OBJECT_ s_ns);
 USER_OBJECT_ R_insertXMLNode(USER_OBJECT_ node, USER_OBJECT_ parent);
 USER_OBJECT_ R_saveXMLDOM(USER_OBJECT_ sdoc, USER_OBJECT_ sfileName, USER_OBJECT_ compression, USER_OBJECT_ sindent, USER_OBJECT_ prefix);
 
+
+USER_OBJECT_ R_createXMLNodeRef(xmlNodePtr node);
+USER_OBJECT_ R_createXMLDocRef(xmlDocPtr doc);
+
 #endif
 
